@@ -48,7 +48,11 @@ import Test.ChasingBottoms.SemanticOrd
 import Test.ChasingBottoms.TestUtilities
 import Test.QuickCheck
 #if MIN_VERSION_QuickCheck(2,7,0)
-  hiding (infiniteListOf)
+  hiding ( infiniteListOf
+#if MIN_VERSION_QuickCheck(2,10,0)
+         , function
+#endif
+         )
 #endif
 #if MIN_VERSION_QuickCheck(2,7,0)
 import Test.QuickCheck.Gen.Unsafe (promote)
